aboutsummaryrefslogtreecommitdiffstats
path: root/java
diff options
context:
space:
mode:
Diffstat (limited to 'java')
-rw-r--r--java/res/values/config-auto-correction-thresholds.xml2
-rw-r--r--java/res/values/emoji-categories.xml2
-rw-r--r--java/res/xml-sw600dp/key_styles_common.xml2
-rw-r--r--java/res/xml/key_styles_common.xml2
-rw-r--r--java/res/xml/prefs_screen_accounts.xml2
-rw-r--r--java/src/com/android/inputmethod/dictionarypack/MetadataDbHelper.java2
-rw-r--r--java/src/com/android/inputmethod/event/Event.java2
-rw-r--r--java/src/com/android/inputmethod/keyboard/KeyboardView.java2
-rw-r--r--java/src/com/android/inputmethod/keyboard/internal/KeyboardTextsTable.java2
-rw-r--r--java/src/com/android/inputmethod/latin/BinaryDictionaryFileDumper.java2
-rw-r--r--java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java6
-rw-r--r--java/src/com/android/inputmethod/latin/InputAttributes.java2
-rw-r--r--java/src/com/android/inputmethod/latin/RichInputMethodSubtype.java36
-rw-r--r--java/src/com/android/inputmethod/latin/Suggest.java2
-rw-r--r--java/src/com/android/inputmethod/latin/about/AboutPreferences.java2
-rw-r--r--java/src/com/android/inputmethod/latin/inputlogic/InputLogic.java4
-rw-r--r--java/src/com/android/inputmethod/latin/settings/CustomInputStylePreference.java2
-rw-r--r--java/src/com/android/inputmethod/latin/utils/CapsModeUtils.java4
-rw-r--r--java/src/com/android/inputmethod/latin/utils/RecapitalizeStatus.java2
19 files changed, 40 insertions, 40 deletions
diff --git a/java/res/values/config-auto-correction-thresholds.xml b/java/res/values/config-auto-correction-thresholds.xml
index fc701c7ff..668f90e73 100644
--- a/java/res/values/config-auto-correction-thresholds.xml
+++ b/java/res/values/config-auto-correction-thresholds.xml
@@ -37,7 +37,7 @@
<!-- Chosen to be slightly less than the "aggressive" threshold. This is the threshold for
a mildly plausible suggestion given the input; if no "plausible" suggestion is present
for a language, it's a strong indicator the user is not typing in this language, so we
- may be more forgiving of whitelist entries in another language. -->
+ may be more forgiving of allowlist entries in another language. -->
<string name="plausibility_threshold" translatable="false">0.065</string>
<!-- The index of the auto correction threshold values array. -->
diff --git a/java/res/values/emoji-categories.xml b/java/res/values/emoji-categories.xml
index ce82a8b40..ae5ccc74a 100644
--- a/java/res/values/emoji-categories.xml
+++ b/java/res/values/emoji-categories.xml
@@ -22,7 +22,7 @@
There is another emoji code point list for JB-MR2 and KLP and later under
res/xml/values-v1[89].-->
<resources>
- <!-- Dummy codeArrays for recents emoji keyboard.
+ <!-- Placeholder codeArrays for recents emoji keyboard.
Do not remove these keys, because they are used as a template. -->
<array
name="emoji_recents"
diff --git a/java/res/xml-sw600dp/key_styles_common.xml b/java/res/xml-sw600dp/key_styles_common.xml
index ea8f29250..3d25f4295 100644
--- a/java/res/xml-sw600dp/key_styles_common.xml
+++ b/java/res/xml-sw600dp/key_styles_common.xml
@@ -38,7 +38,7 @@
<include
latin:keyboardLayout="@xml/key_styles_settings" />
<!-- Functional key styles -->
- <!-- Base style for shift key. A single space is used for dummy label in moreKeys. -->
+ <!-- Base style for shift key. A single space is used for base label in moreKeys. -->
<key-style
latin:styleName="baseForShiftKeyStyle"
latin:keyActionFlags="noKeyPreview"
diff --git a/java/res/xml/key_styles_common.xml b/java/res/xml/key_styles_common.xml
index d85438d99..fbc44da38 100644
--- a/java/res/xml/key_styles_common.xml
+++ b/java/res/xml/key_styles_common.xml
@@ -38,7 +38,7 @@
<include
latin:keyboardLayout="@xml/key_styles_settings" />
<!-- Functional key styles -->
- <!-- Base style for shift key. A single space is used for dummy label in moreKeys. -->
+ <!-- Base style for shift key. A single space is used for base label in moreKeys. -->
<key-style
latin:styleName="baseForShiftKeyStyle"
latin:keyActionFlags="noKeyPreview"
diff --git a/java/res/xml/prefs_screen_accounts.xml b/java/res/xml/prefs_screen_accounts.xml
index 75fff52c6..415b0b4e1 100644
--- a/java/res/xml/prefs_screen_accounts.xml
+++ b/java/res/xml/prefs_screen_accounts.xml
@@ -19,7 +19,7 @@
xmlns:latin="http://schemas.android.com/apk/res/com.android.inputmethod.latin"
android:title="@string/settings_screen_accounts">
- <!-- This preference is a dummy view of the underlying preference.
+ <!-- This preference is a fake view of the underlying preference.
This isn't persisted and the summary/title is refreshed by the fragment
after inspecting the underlying account preference. -->
<Preference
diff --git a/java/src/com/android/inputmethod/dictionarypack/MetadataDbHelper.java b/java/src/com/android/inputmethod/dictionarypack/MetadataDbHelper.java
index 7d01351b4..94dd7a1c9 100644
--- a/java/src/com/android/inputmethod/dictionarypack/MetadataDbHelper.java
+++ b/java/src/com/android/inputmethod/dictionarypack/MetadataDbHelper.java
@@ -870,7 +870,7 @@ public class MetadataDbHelper extends SQLiteOpenHelper {
*/
public static void updateClientInfo(final Context context, final String clientId,
final ContentValues values) {
- // Sanity check the content values
+ // Validity check the content values
final String valuesClientId = values.getAsString(CLIENT_CLIENT_ID_COLUMN);
final String valuesMetadataUri = values.getAsString(CLIENT_METADATA_URI_COLUMN);
final String valuesMetadataAdditionalId =
diff --git a/java/src/com/android/inputmethod/event/Event.java b/java/src/com/android/inputmethod/event/Event.java
index e3b1afc53..58d878fbe 100644
--- a/java/src/com/android/inputmethod/event/Event.java
+++ b/java/src/com/android/inputmethod/event/Event.java
@@ -123,7 +123,7 @@ public class Event {
mSuggestedWordInfo = suggestedWordInfo;
mFlags = flags;
mNextEvent = next;
- // Sanity checks
+ // Validity checks
// mSuggestedWordInfo is non-null if and only if the type is SUGGESTION_PICKED
if (EVENT_TYPE_SUGGESTION_PICKED == mEventType) {
if (null == mSuggestedWordInfo) {
diff --git a/java/src/com/android/inputmethod/keyboard/KeyboardView.java b/java/src/com/android/inputmethod/keyboard/KeyboardView.java
index 27e538cb7..faa21070e 100644
--- a/java/src/com/android/inputmethod/keyboard/KeyboardView.java
+++ b/java/src/com/android/inputmethod/keyboard/KeyboardView.java
@@ -100,7 +100,7 @@ public class KeyboardView extends View {
private static final float MAX_LABEL_RATIO = 0.90f;
// Main keyboard
- // TODO: Consider having a dummy keyboard object to make this @Nonnull
+ // TODO: Consider having a base keyboard object to make this @Nonnull
@Nullable
private Keyboard mKeyboard;
@Nonnull
diff --git a/java/src/com/android/inputmethod/keyboard/internal/KeyboardTextsTable.java b/java/src/com/android/inputmethod/keyboard/internal/KeyboardTextsTable.java
index b50c0a86a..7dfb5328c 100644
--- a/java/src/com/android/inputmethod/keyboard/internal/KeyboardTextsTable.java
+++ b/java/src/com/android/inputmethod/keyboard/internal/KeyboardTextsTable.java
@@ -60,7 +60,7 @@ public final class KeyboardTextsTable {
if (text != null) {
return text;
}
- // Sanity check.
+ // Validity check.
if (index >= 0 && index < TEXTS_DEFAULT.length) {
return TEXTS_DEFAULT[index];
}
diff --git a/java/src/com/android/inputmethod/latin/BinaryDictionaryFileDumper.java b/java/src/com/android/inputmethod/latin/BinaryDictionaryFileDumper.java
index 1fe0a4cce..648610c86 100644
--- a/java/src/com/android/inputmethod/latin/BinaryDictionaryFileDumper.java
+++ b/java/src/com/android/inputmethod/latin/BinaryDictionaryFileDumper.java
@@ -523,7 +523,7 @@ public final class BinaryDictionaryFileDumper {
}
// Read from metadata file in resources to get the baseline dictionary info.
- // This ensures we start with a sane list of available dictionaries.
+ // This ensures we start with a valid list of available dictionaries.
final int metadataResourceId = context.getResources().getIdentifier("metadata",
"raw", DictionaryInfoUtils.RESOURCE_PACKAGE_NAME);
if (metadataResourceId == 0) {
diff --git a/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java b/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
index 60016371b..c13f0e20a 100644
--- a/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
+++ b/java/src/com/android/inputmethod/latin/BinaryDictionaryGetter.java
@@ -196,8 +196,8 @@ final public class BinaryDictionaryGetter {
}
// ## HACK ## we prevent usage of a dictionary before version 18. The reason for this is, since
- // those do not include whitelist entries, the new code with an old version of the dictionary
- // would lose whitelist functionality.
+ // those do not include allowlist entries, the new code with an old version of the dictionary
+ // would lose allowlist functionality.
private static boolean hackCanUseDictionaryFile(final File file) {
if (!SHOULD_USE_DICT_VERSION) {
return true;
@@ -211,7 +211,7 @@ final public class BinaryDictionaryGetter {
// No version in the options : the format is unexpected
return false;
}
- // Version 18 is the first one to include the whitelist
+ // Version 18 is the first one to include the allowlist.
// Obviously this is a big ## HACK ##
return Integer.parseInt(version) >= 18;
} catch (java.io.FileNotFoundException e) {
diff --git a/java/src/com/android/inputmethod/latin/InputAttributes.java b/java/src/com/android/inputmethod/latin/InputAttributes.java
index 37effeead..86c7810f4 100644
--- a/java/src/com/android/inputmethod/latin/InputAttributes.java
+++ b/java/src/com/android/inputmethod/latin/InputAttributes.java
@@ -66,7 +66,7 @@ public final class InputAttributes {
|| InputTypeUtils.isVisiblePasswordInputType(inputType);
if (inputClass != InputType.TYPE_CLASS_TEXT) {
// If we are not looking at a TYPE_CLASS_TEXT field, the following strange
- // cases may arise, so we do a couple sanity checks for them. If it's a
+ // cases may arise, so we do a couple validity checks for them. If it's a
// TYPE_CLASS_TEXT field, these special cases cannot happen, by construction
// of the flags.
if (null == editorInfo) {
diff --git a/java/src/com/android/inputmethod/latin/Suggest.java b/java/src/com/android/inputmethod/latin/Suggest.java
index 7ccefd2dd..da23617af 100644
--- a/java/src/com/android/inputmethod/latin/Suggest.java
+++ b/java/src/com/android/inputmethod/latin/Suggest.java
@@ -225,7 +225,7 @@ public final class Suggest {
// TODO: now that we have personalization, we may want to re-evaluate this decision
|| !mDictionaryFacilitator.hasAtLeastOneInitializedMainDictionary()
// If the first suggestion is a shortcut we never auto-correct to it, regardless
- // of how strong it is (whitelist entries are not KIND_SHORTCUT but KIND_WHITELIST).
+ // of how strong it is (allowlist entries are not KIND_SHORTCUT but KIND_WHITELIST).
// TODO: we may want to have shortcut-only entries auto-correct in the future.
|| suggestionResults.first().isKindOf(SuggestedWordInfo.KIND_SHORTCUT)) {
hasAutoCorrection = false;
diff --git a/java/src/com/android/inputmethod/latin/about/AboutPreferences.java b/java/src/com/android/inputmethod/latin/about/AboutPreferences.java
index f60b189f1..ec7e6def5 100644
--- a/java/src/com/android/inputmethod/latin/about/AboutPreferences.java
+++ b/java/src/com/android/inputmethod/latin/about/AboutPreferences.java
@@ -19,7 +19,7 @@ package com.android.inputmethod.latin.about;
import android.app.Fragment;
/**
- * Dummy class of AboutPreferences. Never use this.
+ * Placeholer class of AboutPreferences. Never use this.
*/
public final class AboutPreferences extends Fragment {
private AboutPreferences() {
diff --git a/java/src/com/android/inputmethod/latin/inputlogic/InputLogic.java b/java/src/com/android/inputmethod/latin/inputlogic/InputLogic.java
index 1dd5850f8..a7804a13f 100644
--- a/java/src/com/android/inputmethod/latin/inputlogic/InputLogic.java
+++ b/java/src/com/android/inputmethod/latin/inputlogic/InputLogic.java
@@ -805,7 +805,7 @@ public final class InputLogic {
if (SpaceState.PHANTOM == inputTransaction.mSpaceState
&& !settingsValues.isWordConnector(codePoint)) {
if (isComposingWord) {
- // Sanity check
+ // Validity check
throw new RuntimeException("Should not be composing here");
}
insertAutomaticSpaceIfOptionsAndTextAllow(settingsValues);
@@ -1370,7 +1370,7 @@ public final class InputLogic {
* @return whether it's fine to apply the transformation after this code point.
*/
private static boolean canBeFollowedByDoubleSpacePeriod(final int codePoint) {
- // TODO: This should probably be a blacklist rather than a whitelist.
+ // TODO: This should probably be a denylist rather than a allowlist.
// TODO: This should probably be language-dependant...
return Character.isLetterOrDigit(codePoint)
|| codePoint == Constants.CODE_SINGLE_QUOTE
diff --git a/java/src/com/android/inputmethod/latin/settings/CustomInputStylePreference.java b/java/src/com/android/inputmethod/latin/settings/CustomInputStylePreference.java
index 21ea8f859..44a98c1be 100644
--- a/java/src/com/android/inputmethod/latin/settings/CustomInputStylePreference.java
+++ b/java/src/com/android/inputmethod/latin/settings/CustomInputStylePreference.java
@@ -330,7 +330,7 @@ final class CustomInputStylePreference extends DialogPreference
R.array.predefined_layouts);
// TODO: Should filter out already existing combinations of locale and layout.
for (final String layout : predefinedKeyboardLayoutSet) {
- // This is a dummy subtype with NO_LANGUAGE, only for display.
+ // This is a placeholder for a subtype with NO_LANGUAGE, only for display.
final InputMethodSubtype subtype =
AdditionalSubtypeUtils.createDummyAdditionalSubtype(
SubtypeLocaleUtils.NO_LANGUAGE, layout);
diff --git a/java/src/com/android/inputmethod/latin/utils/CapsModeUtils.java b/java/src/com/android/inputmethod/latin/utils/CapsModeUtils.java
index 0dbc7c858..47f65499d 100644
--- a/java/src/com/android/inputmethod/latin/utils/CapsModeUtils.java
+++ b/java/src/com/android/inputmethod/latin/utils/CapsModeUtils.java
@@ -194,10 +194,10 @@ public final class CapsModeUtils {
// English is a special case in that "American typography" rules, which are the most common
// in English, state that a sentence terminator immediately following a quotation mark
// should be swapped with it and de-duplicated (included in the quotation mark),
- // e.g. <<Did he say, "let's go home?">>
+ // e.g. <<Did they say, "let's go home?">>
// No other language has such a rule as far as I know, instead putting inside the quotation
// mark as the exact thing quoted and handling the surrounding punctuation independently,
- // e.g. <<Did he say, "let's go home"?>>
+ // e.g. <<Did they say, "let's go home"?>>
if (spacingAndPunctuations.mUsesAmericanTypography) {
for (; j > 0; j--) {
// Here we look to go over any closing punctuation. This is because in dominant
diff --git a/java/src/com/android/inputmethod/latin/utils/RecapitalizeStatus.java b/java/src/com/android/inputmethod/latin/utils/RecapitalizeStatus.java
index a381649a4..737e33228 100644
--- a/java/src/com/android/inputmethod/latin/utils/RecapitalizeStatus.java
+++ b/java/src/com/android/inputmethod/latin/utils/RecapitalizeStatus.java
@@ -81,7 +81,7 @@ public class RecapitalizeStatus {
private static final int[] EMPTY_STORTED_SEPARATORS = {};
public RecapitalizeStatus() {
- // By default, initialize with dummy values that won't match any real recapitalize.
+ // By default, initialize with fake values that won't match any real recapitalize.
start(-1, -1, "", Locale.getDefault(), EMPTY_STORTED_SEPARATORS);
stop();
}
diff --git a/java/src/com/android/inputmethod/latin/RichInputMethodSubtype.java b/java/src/com/android/inputmethod/latin/RichInputMethodSubtype.java
index cc589229e..941149895 100644
--- a/java/src/com/android/inputmethod/latin/RichInputMethodSubtype.java
+++ b/java/src/com/android/inputmethod/latin/RichInputMethodSubtype.java
@@ -174,35 +174,35 @@ public class RichInputMethodSubtype {
}
}
- // Dummy no language QWERTY subtype. See {@link R.xml.method}.
- private static final int SUBTYPE_ID_OF_DUMMY_NO_LANGUAGE_SUBTYPE = 0xdde0bfd3;
- private static final String EXTRA_VALUE_OF_DUMMY_NO_LANGUAGE_SUBTYPE =
+ // Placeholer for no language QWERTY subtype. See {@link R.xml.method}.
+ private static final int SUBTYPE_ID_OF_PLACEHOLDER_NO_LANGUAGE_SUBTYPE = 0xdde0bfd3;
+ private static final String EXTRA_VALUE_OF_PLACEHOLDER_NO_LANGUAGE_SUBTYPE =
"KeyboardLayoutSet=" + SubtypeLocaleUtils.QWERTY
+ "," + Constants.Subtype.ExtraValue.ASCII_CAPABLE
+ "," + Constants.Subtype.ExtraValue.ENABLED_WHEN_DEFAULT_IS_NOT_ASCII_CAPABLE
+ "," + Constants.Subtype.ExtraValue.EMOJI_CAPABLE;
@Nonnull
- private static final RichInputMethodSubtype DUMMY_NO_LANGUAGE_SUBTYPE =
+ private static final RichInputMethodSubtype PLACEHOLDER_NO_LANGUAGE_SUBTYPE =
new RichInputMethodSubtype(InputMethodSubtypeCompatUtils.newInputMethodSubtype(
R.string.subtype_no_language_qwerty, R.drawable.ic_ime_switcher_dark,
SubtypeLocaleUtils.NO_LANGUAGE, KEYBOARD_MODE,
- EXTRA_VALUE_OF_DUMMY_NO_LANGUAGE_SUBTYPE,
+ EXTRA_VALUE_OF_PLACEHOLDER_NO_LANGUAGE_SUBTYPE,
false /* isAuxiliary */, false /* overridesImplicitlyEnabledSubtype */,
- SUBTYPE_ID_OF_DUMMY_NO_LANGUAGE_SUBTYPE));
+ SUBTYPE_ID_OF_PLACEHOLDER_NO_LANGUAGE_SUBTYPE));
// Caveat: We probably should remove this when we add an Emoji subtype in {@link R.xml.method}.
- // Dummy Emoji subtype. See {@link R.xml.method}.
- private static final int SUBTYPE_ID_OF_DUMMY_EMOJI_SUBTYPE = 0xd78b2ed0;
- private static final String EXTRA_VALUE_OF_DUMMY_EMOJI_SUBTYPE =
+ // Placeholder Emoji subtype. See {@link R.xml.method}.
+ private static final int SUBTYPE_ID_OF_PLACEHOLDER_EMOJI_SUBTYPE = 0xd78b2ed0;
+ private static final String EXTRA_VALUE_OF_PLACEHOLDER_EMOJI_SUBTYPE =
"KeyboardLayoutSet=" + SubtypeLocaleUtils.EMOJI
+ "," + Constants.Subtype.ExtraValue.EMOJI_CAPABLE;
@Nonnull
- private static final RichInputMethodSubtype DUMMY_EMOJI_SUBTYPE = new RichInputMethodSubtype(
+ private static final RichInputMethodSubtype PLACEHOLDER_EMOJI_SUBTYPE = new RichInputMethodSubtype(
InputMethodSubtypeCompatUtils.newInputMethodSubtype(
R.string.subtype_emoji, R.drawable.ic_ime_switcher_dark,
SubtypeLocaleUtils.NO_LANGUAGE, KEYBOARD_MODE,
- EXTRA_VALUE_OF_DUMMY_EMOJI_SUBTYPE,
+ EXTRA_VALUE_OF_PLACEHOLDER_EMOJI_SUBTYPE,
false /* isAuxiliary */, false /* overridesImplicitlyEnabledSubtype */,
- SUBTYPE_ID_OF_DUMMY_EMOJI_SUBTYPE));
+ SUBTYPE_ID_OF_PLACEHOLDER_EMOJI_SUBTYPE));
private static RichInputMethodSubtype sNoLanguageSubtype;
private static RichInputMethodSubtype sEmojiSubtype;
@@ -222,9 +222,9 @@ public class RichInputMethodSubtype {
return noLanguageSubtype;
}
Log.w(TAG, "Can't find any language with QWERTY subtype");
- Log.w(TAG, "No input method subtype found; returning dummy subtype: "
- + DUMMY_NO_LANGUAGE_SUBTYPE);
- return DUMMY_NO_LANGUAGE_SUBTYPE;
+ Log.w(TAG, "No input method subtype found; returning placeholder subtype: "
+ + PLACEHOLDER_NO_LANGUAGE_SUBTYPE);
+ return PLACEHOLDER_NO_LANGUAGE_SUBTYPE;
}
@Nonnull
@@ -243,8 +243,8 @@ public class RichInputMethodSubtype {
return emojiSubtype;
}
Log.w(TAG, "Can't find emoji subtype");
- Log.w(TAG, "No input method subtype found; returning dummy subtype: "
- + DUMMY_EMOJI_SUBTYPE);
- return DUMMY_EMOJI_SUBTYPE;
+ Log.w(TAG, "No input method subtype found; returning placeholder subtype: "
+ + PLACEHOLDER_EMOJI_SUBTYPE);
+ return PLACEHOLDER_EMOJI_SUBTYPE;
}
}